==> haskell-data-default-instances-dlist-0.0.1.2-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-dlist
version:              0.0.1.2
visibility:           public
id:                   data-default-instances-dlist-0.0.1.2-DQTXU9LByEnGZ9HYv9g238
key:                  data-default-instances-dlist-0.0.1.2-DQTXU9LByEnGZ9HYv9g238
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in dlist
description:
    This module defines a '\''Default'\'' instance for the type '\''DList'\''.

category:             Data
abi:                  eed0ccbe7f5b577f9238f036fafd1754
exposed:              True
exposed-modules:      Data.Default.Instances.DList
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-dlist-0.0.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-dlist-0.0.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-dlist-0.0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-dlist
hs-libraries:
    HSdata-default-instances-dlist-0.0.1.2-DQTXU9LByEnGZ9HYv9g238

depends:
    base-4.17.2.1 data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb
    dlist-1.0-IJrTDexief3J1GR3vYsW3H

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-dlist/html/data-default-instances-dlist.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-dlist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-dlist-0.0.1.2-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-dlist
version:              0.0.1.2
visibility:           public
id:                   data-default-instances-dlist-0.0.1.2-DGM4Amkjoyw9A6KD5II8wa
key:                  data-default-instances-dlist-0.0.1.2-DGM4Amkjoyw9A6KD5II8wa
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in dlist
description:
    This module defines a '\''Default'\'' instance for the type '\''DList'\''.

category:             Data
abi:                  7225c4a26e197c11d0fdc013db63c27f
exposed:              True
exposed-modules:      Data.Default.Instances.DList
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-dlist-0.0.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-dlist-0.0.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-dlist-0.0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-dlist
hs-libraries:
    HSdata-default-instances-dlist-0.0.1.2-DGM4Amkjoyw9A6KD5II8wa

depends:
    base-4.17.2.1 data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb
    dlist-1.0-BKgPi70fx5AJreCYiKxIIN

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-dlist/html/data-default-instances-dlist.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-dlist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
